@@ -28,8 +28,8 @@ except ImportError:
 CLASS_COLOR = {'Pre-explosion': 'grey', 'SNIa-norm': 'tab:green', 'SNIbc': 'tab:orange', 'SNII': 'tab:blue',
                'SNIa-91bg': 'tab:red', 'SNIa-x': 'tab:purple', 'point-Ia': 'tab:brown', 'Kilonova': '#aaffc3',
                'SLSN-I': 'tab:olive', 'PISN': 'tab:cyan', 'ILOT': '#FF1493', 'CART': 'navy', 'TDE': 'tab:pink',
-               'AGN': 'bisque',
-               'Ia': 'tab:green', 'SLSN': 'tab:olive', 'II': 'tab:blue', 'IIn': 'tab:brown', 'Ibc': 'tab:orange'}
+               'AGN': 'bisque', 'Ia': 'tab:green', 'SLSN': 'tab:olive', 'II': 'tab:blue', 'IIn': 'tab:brown',
+               'Ibc': 'tab:orange', 'CC': 'blue'}
 PB_COLOR = {'u': 'tab:blue', 'g': 'tab:blue', 'r': 'tab:orange', 'i': 'm', 'z': 'k', 'Y': 'y'}
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -104,8 +104,6 @@ class Classify(object):
             self.maxtime = maxtime
             self.timestep = timestep
         else:
-            if not (model_filepath == '' and os.path.exists(model_filepath)):
-                print("Invalid keras model. Using default model set by model_name.")
             if model_name == 'ZTF_known_redshift':
                 self.model_filepath = os.path.join(SCRIPT_DIR, 'ZTF_known_redshift.hdf5')
                 self.contextual_info = ['redshift',]
