@@ -31,15 +31,14 @@ COLCLASS = {'Pre-explosion': 'grey', 'SNIa-norm': 'tab:green', 'SNIbc': 'tab:ora
             'SLSN-I': 'tab:olive', 'PISN': 'tab:cyan', 'ILOT': '#FF1493', 'CART': 'navy', 'TDE': 'tab:pink',
             'AGN': 'bisque'}
 COLPB = {'u': 'tab:blue', 'g': 'tab:blue', 'r': 'tab:orange', 'i': 'm', 'z': 'k', 'Y': 'y'}
-MARKPB = {'g': 'o', 'r': 's'}
-ALPHAPB = {'g': 0.3, 'r': 1.}
+MARKPB = {'g': 'o', 'r': 's', 'i': 'x'}
+ALPHAPB = {'g': 0.3, 'r': 1., 'i': 0.7}
 WLOGLOSS_WEIGHTS = [1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2]
 MINTIME = -70
 MAXTIME = 80
 
-
 def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None, orig_lc_test=None, objids_test=None,
-                 passbands=('g', 'r')):
+                 passbands=('g', 'r'), num_ex_vs_time=100, init_day_since_trigger=-25):
     scores = model.evaluate(X_test, y_test, verbose=0)
     print("Accuracy: %.2f%%" % (scores[1] * 100))
 
@@ -53,7 +52,8 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
     print("Accuracy is: {}/{} = {}".format(accuracy, len(y_test_indexes.flatten()),
                                            accuracy / len(y_test_indexes.flatten())))
 
-    class_names = ["Pre-explosion"] + class_names
+    if "Pre-explosion" not in class_names:
+        class_names = ["Pre-explosion"] + class_names
 
     # Set trailing zeros to -200
     for i in range(timesX_test.shape[0]):
@@ -71,12 +71,12 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
     matplotlib.rc('font', **font)
 
     # Plot classification example vs time
-    for idx in np.arange(0, 100):
+    for idx in np.arange(0, num_ex_vs_time):
         true_class = int(max(y_test_indexes[idx]))
-        print(true_class)
+        # print(true_class)
         # if true_class != 1:
         #     continue
-        print("Plotting example vs time", idx, objids_test[idx])
+        print("Plotting example vs time number {}, id \"{}\"...".format(idx, objids_test[idx]))
         argmax = timesX_test[idx].argmax() + 1
 
         lc_data = orig_lc_test[idx]
@@ -95,10 +95,10 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
             pbmask = lc_data['passband'] == pb
             # masktime = (lc_data[pbmask]['time'] > MINTIME) & (lc_data[pbmask]['time'] < MAXTIME)
             ax1.errorbar(lc_data[pbmask]['time'], lc_data[pbmask]['flux'],
-                         yerr=lc_data[pbmask]['fluxErr'], fmt=MARKPB[pb], label=pb, c=COLPB[pb],
+                         yerr=lc_data[pbmask]['fluxErr'], fmt='.', label=pb, c=COLPB[pb],
                          lw=3, markersize=10, alpha=0.2)
             ax1.plot(timesX_test[idx][:argmax], X_test[idx][:, pbidx][:argmax], c=COLPB[pb],
-                     lw=3)  # , markersize=10, marker=MARKPB[pb])
+                     lw=3)  # , markersize=10, marker='.'
 
         true_class = int(max(y_test_indexes[idx]))
         ax1.axvline(x=0, color='k', linestyle='-', linewidth=1)
@@ -212,7 +212,7 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
             for pbidx, pb in enumerate(passbands):
                 if pb not in used_passbands:
                     continue
-                # ax1.plot(timesX_test[idx][:argmax][:int(i+1)], X_test[idx][:, pbidx][:argmax][:int(i+1)], label=pb, c=COLPB[pb], lw=3)#, markersize=10, marker=MARKPB[pb])
+                # ax1.plot(timesX_test[idx][:argmax][:int(i+1)], X_test[idx][:, pbidx][:argmax][:int(i+1)], label=pb, c=COLPB[pb], lw=3)#, markersize=10, marker='.')
                 if i + 1 >= len(new_t):
                     break
                 # If less than 0.4 day gap in times skip
@@ -222,7 +222,7 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
                 dea = [lc_data[pbmask]['time'] < new_t[int(i + 1)]]
 
                 ax1.errorbar(np.array(lc_data[pbmask]['time'])[dea], np.array(lc_data[pbmask]['flux'])[dea],
-                             yerr=np.array(lc_data[pbmask]['fluxErr'])[dea], fmt=MARKPB[pb], label=pb,
+                             yerr=np.array(lc_data[pbmask]['fluxErr'])[dea], fmt='.', label=pb,
                              c=COLPB[pb], lw=3, markersize=10)
 
             for classnum, classname in enumerate(class_names):
@@ -248,6 +248,9 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
     # fig = plt.figure(figsize=(13, 12))
     for classnum, classname in enumerate(class_names):
         correct_predictions_inclass = (y_test_indexes == classnum) & (y_pred_indexes == y_test_indexes)
+        if not np.any(correct_predictions_inclass):
+            print("There are no correct predictions for class \"{}\".".format(classname))
+            continue
         time_bins = np.arange(-150, 150, 3.)
 
         times_binned_indexes = np.digitize(timesX_test, bins=time_bins, right=True)
@@ -259,24 +262,23 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
         time_list_indexes2_inclass = time_list_indexes2_inclass[time_list_indexes2_inclass < len(time_bins)]
         count_objects_vs_binned_time_inclass = count_objects_vs_binned_time_inclass[time_list_indexes2_inclass < len(time_bins)]
 
-        start_time_index = int(np.where(time_list_indexes2_inclass == time_list_indexes_inclass[0])[0])
-        end_time_index = int(np.where(time_list_indexes2_inclass == time_list_indexes_inclass[-1])[0]) + 1
+        start_time_index = int(np.where(time_list_indexes2_inclass == time_list_indexes_inclass[1])[0])
+        end_time_index = int(np.where(time_list_indexes2_inclass == time_list_indexes_inclass[-1])[0])
 
         try:
-            accuracy_vs_time_inclass = count_correct_vs_binned_time_inclass[1:] / count_objects_vs_binned_time_inclass[start_time_index:end_time_index]
+            accuracy_vs_time_inclass = count_correct_vs_binned_time_inclass[1:] / count_objects_vs_binned_time_inclass[start_time_index:end_time_index+1]
         except Exception as e:
             print(e)
             continue
 
         try:
-            assert np.all(time_list_indexes_inclass[1:] == time_list_indexes2_inclass[start_time_index:end_time_index])
+            assert np.all(time_list_indexes_inclass[1:] == time_list_indexes2_inclass[start_time_index:end_time_index+1])
         except Exception as e:
-            import pdb; pdb.set_trace()
             print(e)
             pass
 
         plt.plot(time_bins[time_list_indexes_inclass[1:]], accuracy_vs_time_inclass, '-', label=classname, color=COLORS[classnum], lw=3)
-    plt.xlim(left=-35, right=70)
+    plt.xlim(left=init_day_since_trigger - 10, right=70)
     plt.xlabel("Days since trigger (rest frame)")
     plt.ylabel("Classification accuracy")
     plt.legend(frameon=True, fontsize=25, ncol=2, loc=0)  # , bbox_to_anchor=(0.05, -0.1))
@@ -317,7 +319,7 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
     images_cf, images_roc, images_pr = [], [], []
     roc_auc, pr_auc = {}, {}
     wlogloss = {}
-    for i, days_since_trigger in enumerate(list(np.arange(0, 75,step=2))):# + list(np.arange(25, 70, step=5))):  # [('early2days', 2), ('late40days', 40)]: # [-25, -20, -15, -10, -5, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70]:
+    for i, days_since_trigger in enumerate(list(np.arange(init_day_since_trigger, 25)) + list(np.arange(25, 70, step=5))):  # [('early2days', 2), ('late40days', 40)]: # [-25, -20, -15, -10, -5, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70]:
         print("Plotting CF matrix", i, days_since_trigger, "days")
         index = np.where(time_bins == days_since_trigger)[0][0]
         y_test_on_day_i = y_test_indexes_days_past_trigger[:, index]
@@ -328,7 +330,7 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
         title = '{} days since trigger'.format(days_since_trigger)
         cnf_matrix = confusion_matrix(y_test_on_day_i, y_pred_on_day_i)
         print(name, cnf_matrix)
-        figname_cf = plot_confusion_matrix(cnf_matrix, classes=class_names[1:], normalize=True, title=title,
+        figname_cf = plot_confusion_matrix(cnf_matrix, classes=class_names, normalize=True, title=title,
                                            fig_dir=fig_dir + '/cf_since_trigger', name=name)
         images_cf.append(imageio.imread(figname_cf))
 
@@ -349,7 +351,7 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
 
         try:
             wlogloss[days_since_trigger] = plasticc_log_loss(to_categorical(y_test_on_day_i, num_classes=nclasses),
-                                                             y_pred_prob_on_day_i, relative_class_weights=WLOGLOSS_WEIGHTS)
+                                                             y_pred_prob_on_day_i, relative_class_weights=WLOGLOSS_WEIGHTS[:len(class_names)])
         except Exception as e:
             print("Cannot compute weighted PLAsTiCC Log Loss.", e)
 
@@ -454,11 +456,11 @@ def plot_metrics(class_names, model, X_test, y_test, fig_dir, timesX_test=None,
     #         if pb in orig_lc_test[idx].keys():
     #             try:
     #                 ax1.errorbar(lc_data[pbmask]['time'], lc_data[pbmask]['flux'],
-    #                              yerr=orig_lc_test[idx][pb]['fluxErr'], fmt=MARKPB[pb], label=pb, c=COLPB[pb],
+    #                              yerr=orig_lc_test[idx][pb]['fluxErr'], fmt='.', label=pb, c=COLPB[pb],
     #                              lw=3, markersize=10)
     #             except KeyError:
     #                 ax1.errorbar(orig_lc_test[idx][pb]['time'], orig_lc_test[idx][pb][5], yerr=orig_lc_test[idx][pb][6],
-    #                              fmt=MARKPB[pb], label=pb, c=COLPB[pb], lw=3, markersize=10)
+    #                              fmt='., label=pb, c=COLPB[pb], lw=3, markersize=10)
     #     true_class = int(max(y_test_indexes[idx]))
     #     ax1.axvline(x=0, color='k', linestyle='-', linewidth=1)
     #     ax2.axvline(x=0, color='k', linestyle='-', linewidth=1)
